@@ -110,13 +110,22 @@ class TemplateRust(Template):
         self._patch_sub_crate("wasm")
         self._patch_sub_crate("abi")
         self._patch_sub_crate("meta")
+        template_name = self._with_underscores(self.template_name)
 
-        logger.info("Patching source code...")
-        self._patch_source_code_files([
+        tests = (self.directory / "tests").glob("*.rs")
+
+        source_code_files = [
+            self.directory / "src" / f"{template_name}.rs",
+            self.directory / "src" / "lib.rs",
             self.directory / "abi" / "src" / "main.rs",
             self.directory / "wasm" / "src" / "lib.rs",
             self.directory / "meta" / "src" / "main.rs",
-        ], ignore_missing=True)
+        ]
+
+        source_code_files.extend(tests)
+
+        logger.info("Patching source code...")
+        self._patch_source_code_files(source_code_files, ignore_missing=True)
         self._patch_source_code_tests()
 
         logger.info("Patching test files...")
@@ -166,13 +175,23 @@ class TemplateRust(Template):
     def _with_underscores(self, name: str) -> str:
         return name.replace('-', '_')
 
+    def _contract_name(self, name: str) -> str:
+        chars = name.replace("-", " ").replace("_", " ").split()
+        return ''.join(i.capitalize() for i in chars[0:])
+
     def _patch_source_code_files(self, source_paths: List[Path], ignore_missing: bool) -> None:
         template_name = self._with_underscores(self.template_name)
         project_name = self._with_underscores(self.project_name)
+        template_contract_name = self._contract_name(self.template_name)
+        project_contract_name = self._contract_name(self.project_name)
 
         self._replace_in_files(
             source_paths,
             [
+                # Example: replace contract name "pub trait SimpleERC20" to "pub trait MyContract"
+                (f"pub trait {template_contract_name}", f"pub trait {project_contract_name}"),
+                # Example: replace "simple_erc20.wasm" to "my_token.wasm"
+                (f"{self.template_name}.wasm", f"{self.project_name}.wasm"),
                 # Example: replace "use simple_erc20::*" to "use my_token::*"
                 (f"use {template_name}::*", f"use {project_name}::*"),
                 # Example: replace "<simple_erc20::AbiProvider>()" to "<my_token::AbiProvider>()"
